==> winnie-0.1.46.tgz: package/clipboard.js <==
'use strict';

var Logger = require('septima-utils/logger');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var Logger__default = /*#__PURE__*/_interopDefaultLegacy(Logger);

function fakeInput() {
  var input = document.createElement('textarea');
  input.style.left = input.style.top = '0px';
  input.style.width = input.style.height = '2em';
  input.style.background = 'transparent';
  input.style.padding = 0;
  input.style.border = 'none';
  input.style.outline = 'none';
  input.style.boxShadow = 'none';
  return input;
}

function write(value) {
  try {
    var input = fakeInput();
    input.value = value;
    document.body.appendChild(input);

    try {
      input.focus();
      input.select();
      document.execCommand('copy');
    } finally {
      document.body.removeChild(input);
    }
  } catch (e) {
    Logger__default['default'].severe("Failed to write to clipboard due to an error:");
    Logger__default['default'].severe(e);
    Logger__default['default'].info("The data is:\n".concat(value));
  }
}

function read() {
  try {
    var input = fakeInput();
    document.body.appendChild(input);

    try {
      input.focus();
      input.select();
      document.execCommand('paste');
      return input.value;
    } finally {
      document.body.removeChild(input);
    }
  } catch (e) {
    Logger__default['default'].severe("Failed to read from clipboard due to an error:");
    Logger__default['default'].severe(e);
  }
}

var Clipboard = {
  read: read,
  write: write
};

module.exports = Clipboard;

==> winnie-0.1.55.tgz: package/clipboard.js <==
'use strict';

var Logger = require('septima-utils/logger');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var Logger__default = /*#__PURE__*/_interopDefaultLegacy(Logger);

function fakeInput() {
  var input = document.createElement('textarea');
  input.style.left = input.style.top = '0px';
  input.style.width = input.style.height = '2em';
  input.style.background = 'transparent';
  input.style.padding = 0;
  input.style.border = 'none';
  input.style.outline = 'none';
  input.style.boxShadow = 'none';
  return input;
}

function write(value) {
  try {
    var input = fakeInput();
    input.value = value;
    document.body.appendChild(input);

    try {
      input.focus();
      input.select();
      document.execCommand('copy');
    } finally {
      document.body.removeChild(input);
    }
  } catch (e) {
    Logger__default["default"].severe("Failed to write to clipboard due to an error:");
    Logger__default["default"].severe(e);
    Logger__default["default"].info("The data is:\n".concat(value));
  }
}

function read() {
  try {
    var input = fakeInput();
    document.body.appendChild(input);

    try {
      input.focus();
      input.select();
      document.execCommand('paste');
      return input.value;
    } finally {
      document.body.removeChild(input);
    }
  } catch (e) {
    Logger__default["default"].severe("Failed to read from clipboard due to an error:");
    Logger__default["default"].severe(e);
  }
}

var Clipboard = {
  read: read,
  write: write
};

module.exports = Clipboard;
